@@ -2,7 +2,7 @@ cmhc_dwelling_types <- c("Single","Semi-detached","Row","Apartment","All")
 cmhc_intended_markets <- c("Homeowner","Rental","Condo","Co-op","All")
 cmhc_type_codes1 <- c("Provinces"=2,"Centres"=3,"Survey Zones"=8,"Census Subdivision"=9,"Neighbourhoods"=10,"Census Tracts"=11)
 cmhc_type_codes2 <- c("Survey Zones"=6,"Census Subdivision"=7,"Neighbourhoods"=8,"Census Tracts"=9)
-cmhc_type_codes3 <- c("Survey Zones"=3,"Census Subdivision"=4,"Neighbourhoods"=5,"Census Tracts"=6)
+cmhc_type_codes3 <- c("Provinces"=1,"Centres"=2,"Survey Zones"=3,"Census Subdivision"=4,"Neighbourhoods"=5,"Census Tracts"=6)
 cmhc_type_codes4 <- c("Survey Zones"=3,"Census Subdivision"=4)
 cmhc_series_dimension_codes1 <- c("Dwelling Type"=1,"Intended Market"=4)
 cmhc_bedroom_types <- c("Bachelor","1 Bedroom","2 Bedroom","3 Bedroom +","Total")
